<?php

if (!isset($content_width)) {
	$content_width = 1170;
}

define('COSMICA_URI', get_template_directory_uri());
define('COSMICA_DIR', get_template_directory());


function cosmica_add_supports() {

    load_theme_textdomain('cosmica', COSMICA_DIR . '/lang');
    add_editor_style(esc_url(COSMICA_URI . '/css/custom-style.css'));
    add_theme_support('automatic-feed-links');

    /*
                 *  add post format options
    */

    add_theme_support('post-formats', array('aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat'));
    add_theme_support("post-thumbnails");
    add_theme_support("title-tag");
    add_theme_support("custom-logo");

    // Add theme support for Custom Header
    $header_args = array(
        'default-image'          => '',
        'width'                  => 1600,
        'height'                 => 300,
        'flex-width'             => true,
        'flex-height'            => true,
        'uploads'                => true,
        'random-default'         => false,
        'header-text'            => true,
        'default-text-color'     => '',
        'wp-head-callback'       => '',
        'admin-head-callback'    => '',
        'admin-preview-callback' => '',
    );
    add_theme_support('custom-header', $header_args);

    // Add theme support for Custom Background
    $background_args = array(
        'default-color'          => '#fff',
        'default-image'          => '',
        'default-repeat'         => '',
        'default-position-x'     => '',
        'default-attachment'     => '',
        'admin-head-callback'    => '',
        'admin-preview-callback' => '',
    );
    add_theme_support('custom-background', $background_args);
    /*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
    */
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
    ));

    add_theme_support('woocommerce');

}
add_action('after_setup_theme', 'cosmica_add_supports');

register_nav_menus(array(
	'primary_menu' => __('Primary Menu', 'cosmica'),
));

function cosmica_register_sidebars() {

	$SidebarArgs2 = array(
		'name'          => __('Right Sidebar', 'cosmica'),
		'id'            => 'right-sidebar',
		'description'   => '',
		'class'         => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>');
	register_sidebar($SidebarArgs2);

	$SidebarArgs3 = array(
		'name'          => __('Footer Sidebar 1', 'cosmica'),
		'id'            => 'footer-sidebar-1',
		'description'   => '',
		'class'         => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>');
	register_sidebar($SidebarArgs3);

	$SidebarArgs4 = array(
		'name'          => __('Footer Sidebar 2', 'cosmica'),
		'id'            => 'footer-sidebar-2',
		'description'   => '',
		'class'         => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>');
	register_sidebar($SidebarArgs4);

	$SidebarArgs5 = array(
		'name'          => __('Footer Sidebar 3', 'cosmica'),
		'id'            => 'footer-sidebar-3',
		'description'   => '',
		'class'         => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widgettitle">',
		'after_title'   => '</h3>');
	register_sidebar($SidebarArgs5);

}

add_action('widgets_init', 'cosmica_register_sidebars');

function cosmica_register_scripts() {

	wp_enqueue_style('cosmica-google-fonts-style', '//fonts.googleapis.com/css?family=Open+Sans:400,600,700,800,300,400italic|Lato:400,400italic,700,900,300');
	wp_enqueue_style('animate', get_template_directory_uri() . "/css/animate.min.css");
	wp_enqueue_style('slicknav', get_template_directory_uri() . "/css/slicknav.min.css");
	wp_enqueue_style('swiper', get_template_directory_uri() . "/css/swiper.min.css");
	wp_enqueue_style('bootstrap', get_template_directory_uri() . "/css/bootstrap.min.css");
	wp_enqueue_style('font-awesome', get_template_directory_uri() . "/css/font-awesome.min.css");
	wp_enqueue_style('cosmica-media-style', get_template_directory_uri() . "/css/media-style.css");
	wp_enqueue_style('cosmica-style', get_stylesheet_uri());

	if (is_singular() && get_option('thread_comments')) { wp_enqueue_script('comment-reply'); 	}
    wp_enqueue_script('wow', get_template_directory_uri() . '/js/wow.min.js', array('jquery'));
    wp_enqueue_script('slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array('jquery'));
    wp_enqueue_script('swiper', get_template_directory_uri() . '/js/swiper.min.js', array('jquery'));
    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'));
    wp_enqueue_script('easing', get_template_directory_uri() . '/js/jquery.easing.1.3.js', array('jquery'));
	wp_enqueue_script('lavalamp', get_template_directory_uri() . '/js/jquery.lavalamp-1.4.min.js', array('jquery'));
	wp_enqueue_script('cosmica-custom-script', get_template_directory_uri() . '/js/custom-script.js', array('jquery'));

	wp_enqueue_script('respond', get_template_directory_uri() . '/js/respond.min.js');
	wp_script_add_data('respond', 'conditional', 'lt IE 9');

	wp_enqueue_script('html5shiv', get_template_directory_uri() . '/js/html5shiv.js');
	wp_script_add_data('html5shiv', 'conditional', 'lt IE 9');

}
add_action('wp_enqueue_scripts', 'cosmica_register_scripts');

function cosmica_custmizer_style() {
	wp_enqueue_style('cosmica-customizer-css', get_template_directory_uri() . '/css/customizer-style.css');
}
add_action('customize_controls_print_styles', 'cosmica_custmizer_style');

function cosmica_is_woocommrce_active() {

	if (class_exists('WooCommerce')) {
		return true;
	} else {
		return false;
	}

}



function cosmica_new_excerpt_more($more) {
	return '';
}
add_filter('excerpt_more', 'cosmica_new_excerpt_more');

function cosmica_entry_date($echo = true) {
	if (has_post_format(array('chat', 'status'))) {
		$format_prefix = _x('%1$s on %2$s', '1: post format name. 2: date', 'cosmica');
	} else {
		$format_prefix = '%2$s';
	}

	$date = sprintf('<span class="date"><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>',
		esc_url(get_permalink()),
		esc_attr(sprintf(__('Permalink to %s', 'cosmica'), the_title_attribute('echo=0'))),
		esc_attr(get_the_date('c')),
		esc_html(sprintf($format_prefix, get_post_format_string(get_post_format()), get_the_date()))
	);

	if ($echo) {
		echo $date;
	}

	return $date;
}

function cosmica_social_links() {

	extract(cosmica_get_theme_var());
	$link_in_new_tab = (absint($social_link_open_in_new_tab)) ? 'target="_blank"' : '';
	?>
                <div class="social-nav">
                    <ul>
                        <li><a href="<?php echo esc_url($social_link_facebook); ?>" class="social-icon ico-facebook" <?php echo $link_in_new_tab; ?>></a></li>
                        <li><a href="<?php echo esc_url($social_link_google); ?>" class="social-icon ico-google" <?php echo $link_in_new_tab; ?>></a></li>
                        <li><a href="<?php echo esc_url($social_link_youtube); ?>" class="social-icon ico-youtube" <?php echo $link_in_new_tab; ?>></a></li>
                        <li><a href="<?php echo esc_url($social_link_twitter); ?>" class="social-icon ico-twitter" <?php echo $link_in_new_tab; ?>></a></li>
                        <li><a href="<?php echo esc_url($social_link_linkedin); ?>" class="social-icon ico-linkedin" <?php echo $link_in_new_tab; ?>></a></li>
                    </ul>
                </div>

<?php
}



require_once get_template_directory() . '/includes/comica-variables.php';
require_once get_template_directory() . '/includes/cosmica-sanitize-cb.php';
require_once get_template_directory() . '/includes/cosmica-customizer.php';

function cosmica_sanitize_text($str) {
	return sanitize_text_field($str);
}